pub enum VariantColor {
Show 26 variants
Amethyst,
Aquamarine,
Blue,
Cobalt,
Cyan,
Emerald,
Gold,
Green,
Grey,
Indigo,
Lime,
Magenta,
Maroon,
Mauve,
Mulberry,
Ocher,
Orange,
Peach,
Red,
Sage,
Teal,
Turquoise,
White,
Yellow,
None,
Unknown,
}Variants
Amethyst
Aquamarine
Blue
Cobalt
Cyan
Emerald
Gold
Green
Grey
Indigo
Lime
Magenta
Maroon
Mauve
Mulberry
Ocher
Orange
Peach
Red
Sage
Teal
Turquoise
White
Yellow
None
For species or genus that do not have color variation.
Unknown
Available on crate feature
allow-unknown only.This should realistically never happen without changes in the logs.