JsonFile

Struct JsonFile 

pub struct JsonFile<R>{ /* private fields */ }
A wrapper around FileWatcher which can be used to read the contents of a JSON file.

Implementations

Source

impl<R> JsonFile<R>

pub fn new<P: AsRef<Path>>( path: P, unblocker: impl Into<Arc<dyn Unblocker>>, ) -> Result<JsonFile<R>, LogFSError>

Creates a new JsonFile from the provided path and unblocker.

pub fn byte_content(&self) -> Result<Vec<u8>, LogFSError>

Returns the current contents of the file as a raw byte vector.

pub fn string_content(&self) -> Result<String, LogFSError>

Returns the current contents of the file as a string.

pub fn content(&self) -> Result<Option<R>, LogFSError>

Returns the current contents of the file as a deserialized object, or None if the file is empty (which happens when the game clears the file before it starts to write.)

pub async fn byte_content_async(&self) -> Result<Vec<u8>, LogFSError>

Available on crate feature asynchronous only.
pub async fn string_content_async(&self) -> Result<String, LogFSError>

Available on crate feature asynchronous only.
pub async fn content_async(&self) -> Result<Option<R>, LogFSError>

Available on crate feature asynchronous only.