AsyncChangedJsonFile

Struct AsyncChangedJsonFile 

pub struct AsyncChangedJsonFile<R>{ /* private fields */ }
Available on crate feature asynchronous only.
Async variant of ChangedJsonFile.

Implementations

Source

impl<R> AsyncChangedJsonFile<R>

pub fn new<P: AsRef<Path>>( path: P, unblocker: impl Into<Arc<dyn Unblocker>>, ) -> Result<AsyncChangedJsonFile<R>, LogFSError>

pub async fn content(&mut self) -> Result<Option<R>, LogFSError>

Returns the current contents of the file as a deserialized object, or None if the contents haven’t changed since the last read or if the file is empty (which happens when the game clears the file before it starts to write.)