pub struct AsyncBlocker { /* private fields */ }Available on crate feature
asynchronous only.Expand description
Blocker that can be used to block in async code.
Implementations
Sourceimpl AsyncBlocker
impl AsyncBlocker
Sourcepub fn new(capacity: usize) -> AsyncBlocker
pub fn new(capacity: usize) -> AsyncBlocker
Create a new AsyncBlocker with the given capacity.
Sourcepub async fn wait(&mut self) -> Result<(), LogFSError>
pub async fn wait(&mut self) -> Result<(), LogFSError>
Block and await the current task until a registered caller unblocks it.