pub struct CommitCrimeEvent {
pub crime_type: Crime,
pub faction: String,
pub fine: Option<u64>,
pub bounty: Option<u64>,
}Expand description
Fired when the player commits a crime.
Fields
crime_type: CrimeThe kind of crime the player committed.
faction: StringThe faction that the player has commited the crime to.
fine: Option<u64>The fine that needs to be paid for the crime.
bounty: Option<u64>The bounty that has been placed on the player for committing the crime.