pub struct DockingRequestedEvent {
pub station_name: String,
pub station_type: StationType,
pub market_id: u64,
pub landing_pads: Option<DockingRequestedEventLandingPads>,
}Expand description
Fired when the player has successfully required permission to dock to a given station.
Fields
station_name: StringThe name of the station the player wants to dock at.
station_type: StationTypeThe kind of station the player wants to dock at.
market_id: u64The market id of the station.
landing_pads: Option<DockingRequestedEventLandingPads>The number of available landing pads at the given station.