pub struct EngineerContributionEvent {
pub engineer: String,
pub engineer_id: Engineer,
pub kind: EngineerContributionEventType,
}Expand description
Fired when the player contributes to an unlock requirement for an engineer.
Fields
engineer: StringThe engineer the player contributed to.
engineer_id: EngineerThe ID of the engineer.
kind: EngineerContributionEventTypeThe kind of contribution the player has made to the engineer.