pub struct EngineerContributionEventBountyContribution {
pub quantity: u32,
pub total_quantity: u32,
}Expand description
Contribution where the plater handed in a number of bounties.
Fields
quantity: u32Number of bounties that were handed in at this moment.
total_quantity: u32The total number of bounties the player has handed in at this engineer so far.