pub struct FileHeaderEvent {
pub part: u8,
pub language: String,
pub odyssey: bool,
pub game_version: String,
pub build: String,
}Expand description
Always the first event that is fired for a log file. In the case where a log file is Continued, the continued log file gets its own file header with a new part number.
Fields
part: u8The part number for the log file. When just starting the game this will always be 1 and this is incremented with each continued log.
language: StringThe language the player has configured.
odyssey: boolWhether the player has Odyssey enabled.
game_version: StringThe version of the game.
build: StringThe internal build number for the version of the game.