pub struct LoadoutEquipModuleEvent {
pub suit_id: u64,
pub suit_name: Suit,
pub suit_name_localized: Option<String>,
pub loadout_id: u64,
pub loadout_name: String,
pub slot_name: SuitSlot,
pub module_name: Weapon,
pub module_name_localized: Option<String>,
pub class: u8,
pub weapon_mods: Vec<WeaponMod>,
pub suit_module_id: u64,
}Expand description
Fired when equipping a module to a suit loadout.
Fields
suit_id: u64The id of the base suit used for the loadout.
suit_name: SuitThe kind of suit used for the loadout.
suit_name_localized: Option<String>The localized name of the suit used for the loadout.
loadout_id: u64The id of the loadout.
loadout_name: StringThe name of the loadout.
slot_name: SuitSlotThe slot where the module was equipped.
module_name: WeaponThe name of the module that was equipped.
module_name_localized: Option<String>The localized module of the module that was equipped.
class: u8The class of the module equipped.
weapon_mods: Vec<WeaponMod>A list of mods that are applied to the equipped module.
suit_module_id: u64The id of the module.