pub struct ModuleSellEvent {
pub market_id: u64,
pub slot: ShipSlot,
pub sell_item: ShipModule,
pub sell_item_localized: Option<String>,
pub sell_price: u64,
pub ship: ShipType,
pub ship_id: u64,
}Expand description
Fired when the player sells a module.
Fields
market_id: u64The market id where the player sold the module.
slot: ShipSlotThe slot the module was installed in.
sell_item: ShipModuleThe module that was sold.
sell_item_localized: Option<String>The localized name of the module that was sold.
sell_price: u64The number of credits received from selling the module.
ship: ShipTypeThe type of the current active ship that the module was installed onto.
ship_id: u64The id of the current active ship that the module was installed on.