pub struct ProgressEvent {
pub combat: u8,
pub trade: u8,
pub explore: u8,
pub empire: u8,
pub federation: u8,
pub cqc: u8,
}Expand description
Includes information about the current progress of the player to the next rank.
Fields
combat: u8Progress of the combat rank between 0-100.
trade: u8Progress of the trade rank between 0-100.
explore: u8Progress of the exploration rank between 0-100.
empire: u8Progress of the empire rank between 0-100.
federation: u8Progress of the federation rank between 0-100.
cqc: u8Trait Implementations
Sourceimpl Clone for ProgressEvent
impl Clone for ProgressEvent
Sourcefn clone(&self) -> ProgressEvent
fn clone(&self) -> ProgressEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProgressEvent
impl Debug for ProgressEvent
Sourceimpl<'de> Deserialize<'de> for ProgressEvent
impl<'de> Deserialize<'de> for ProgressEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ProgressEvent
impl PartialEq for ProgressEvent
Sourcefn eq(&self, other: &ProgressEvent) -> bool
fn eq(&self, other: &ProgressEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ProgressEvent
impl Serialize for ProgressEvent
impl StructuralPartialEq for ProgressEvent