pub enum InternalModule {
Show 62 variants
FrameShiftDrive,
FrameShiftDriveOvercharged,
FrameShiftDriveOverchargedMkII,
PowerPlant,
ModuleReinforcement,
GuardianModuleReinforcement,
GuardianHullReinforcement,
GuardianShieldReinforcement,
MetaAlloyHullReinforcement,
HullReinforcement,
StandardDockingComputer,
AdvancedDockingComputer,
CollectorLimpetController,
DecontaminationLimpetController,
RepairLimpetController,
ProspectorLimpetController,
FuelTransferLimpetController,
ReconLimpetController,
HatchBreakerLimpetController,
ResearchLimpetController,
MiningMultiLimpetController,
MiningMultiLimpetControllerMkII,
XenoMultiLimpetController,
RescueMultiLimpetController,
OperationsMultiLimpetController,
UniversalMultiLimpetController,
ExperimentalWeaponStabilizer,
CargoRack,
LargeCargoRackMkII,
AntiCorrosionCargoRack,
SupercruiseAssist,
Thrusters,
EnhancedPerformanceThrusters,
MkIIAgileBoostThrusters,
GravityOptimisedThrustersMkII,
FuelScoop,
LifeSupport,
ShieldGenerator,
BiWeaveShieldGenerator,
PrismaticShieldGenerator,
ShieldCellBank,
GuardianFSDBooster,
DetailedSurfaceScanner,
PlanetaryVehicleHangar,
PowerDistributor,
Sensors,
AFMU,
FighterHangar,
MkIIVesselHangar,
PassengerCabin,
MkIIPassengerCabin,
FuelTank,
FSDInterdictor,
PlanetApproachSuite,
Refinery,
GuardianHybridPowerPlant,
GuardianHybridPowerDistributor,
BasicDiscoveryScanner,
IntermediateDiscoveryScanner,
AdvancedDiscoveryScanner,
Armor(ArmorModule),
Unknown(String),
}Expand description
The kind of internal module.
Variants
FrameShiftDrive
FrameShiftDriveOvercharged
FrameShiftDriveOverchargedMkII
Mk II SCO Frame Shift Drive, exclusive to Caspian Explorer
PowerPlant
ModuleReinforcement
GuardianModuleReinforcement
GuardianHullReinforcement
GuardianShieldReinforcement
MetaAlloyHullReinforcement
HullReinforcement
StandardDockingComputer
AdvancedDockingComputer
CollectorLimpetController
DecontaminationLimpetController
RepairLimpetController
ProspectorLimpetController
FuelTransferLimpetController
ReconLimpetController
HatchBreakerLimpetController
ResearchLimpetController
MiningMultiLimpetController
MiningMultiLimpetControllerMkII
Mk II Mining Multi-Limpet Controller, exclusive to Type-11 Prospector
XenoMultiLimpetController
RescueMultiLimpetController
OperationsMultiLimpetController
UniversalMultiLimpetController
ExperimentalWeaponStabilizer
CargoRack
LargeCargoRackMkII
Mk II Large Cargo Rack, exclusive to Panther Clipper MkII
AntiCorrosionCargoRack
SupercruiseAssist
Thrusters
EnhancedPerformanceThrusters
MkIIAgileBoostThrusters
Mk II Agile Boost Thrusters, exclusive to Kestrel Mk II
GravityOptimisedThrustersMkII
Mk II Gravity Optimised Thrusters, exclusive to Panther Clipper MkII
FuelScoop
LifeSupport
ShieldGenerator
BiWeaveShieldGenerator
PrismaticShieldGenerator
ShieldCellBank
GuardianFSDBooster
DetailedSurfaceScanner
PlanetaryVehicleHangar
PowerDistributor
Sensors
AFMU
FighterHangar
MkIIVesselHangar
PassengerCabin
MkIIPassengerCabin
FuelTank
FSDInterdictor
PlanetApproachSuite
Refinery
GuardianHybridPowerPlant
GuardianHybridPowerDistributor
BasicDiscoveryScanner
IntermediateDiscoveryScanner
AdvancedDiscoveryScanner
Armor(ArmorModule)
Unknown(String)
Available on crate feature
allow-unknown only.Implementations
Sourceimpl InternalModule
impl InternalModule
Sourcepub fn internal_type(&self) -> InternalType
pub fn internal_type(&self) -> InternalType
Returns whether the module is a core internal or an optional internal.
Sourcepub fn is_core(&self) -> bool
pub fn is_core(&self) -> bool
Returns true if the module is a core internal like engines or powerplant.
Sourcepub fn is_optional(&self) -> bool
pub fn is_optional(&self) -> bool
Returns true if the module is an optional internal like AFMUs and shield generators.
Sourcepub fn is_powerplay_module(&self) -> bool
pub fn is_powerplay_module(&self) -> bool
Whether the module is a module that is unlocked through powerplay.
Sourcepub fn is_guardian_module(&self) -> bool
pub fn is_guardian_module(&self) -> bool
Whether the module is a module that is unlocked using guardian parts at a guardian technology broker.