pub struct ShipHardpointModule {
pub module: HardpointModule,
pub mounting: HardpointMounting,
pub size: HardpointSize,
pub class: ModuleClass,
}Expand description
Contains all the data related to hardpoints. This model is used for both full-sized hardpoint modules and utility modules. Utility modules use HardpointSize::Tiny and full-sized modules use the other sizes.
Fields
module: HardpointModuleThe kind internal module, which can both be full-sized hardpoints and utility modules.
mounting: HardpointMountingThe mounting type the module used which dictate how aiming works. Utility modules always use HardpointMounting::Turreted.
size: HardpointSizeThe size of the module.
class: ModuleClassThe class of the module.
Implementations
Sourceimpl ShipHardpointModule
impl ShipHardpointModule
Sourcepub fn hardpoint_type(&self) -> HardpointType
pub fn hardpoint_type(&self) -> HardpointType
Returns whether the module is a full-sized hardpoint or a utility module.
Sourcepub fn is_full_sized_module(&self) -> bool
pub fn is_full_sized_module(&self) -> bool
Whether the module is a full-sized hardpoint module.
Sourcepub fn is_utility_module(&self) -> bool
pub fn is_utility_module(&self) -> bool
Whether the module is a utility module.
Sourcepub fn is_powerplay_module(&self) -> bool
pub fn is_powerplay_module(&self) -> bool
Whether the module is a module that is unlocked through powerplay.
Sourcepub fn is_guardian_module(&self) -> bool
pub fn is_guardian_module(&self) -> bool
Whether the module is a module that is unlocked using guardian parts at a guardian technology broker.