pub struct StatusContents {
pub flags: Flags,
pub flags2: Flags2,
pub legal_state: LegalStatus,
pub balance: u64,
pub planet_status: Option<PlanetStatus>,
pub kind: StatusKind,
}Expand description
The actual contents of the status file, containing flags for the different states part of the ship can be in and might also contain information about the planet the player is currently close to.
Fields
flags: FlagsThe current flags for the player. These flags are mostly for things that are related to the player’s ship.
flags2: Flags2A second flags field which includes flags for the on-foot status of the player.
legal_state: LegalStatusThe current legal state of the player, indicating whether they are currently at risk of committing a crime.
balance: u64The current credit balance of the player.
planet_status: Option<PlanetStatus>Information about the planet the player is currently close to.
kind: StatusKindDepending on the current state of the game, the status file includes information about either the ship of the player or information about the player when they’re on-foot.